/*
 * Copyright (c) 2011, Felix Opatz
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * * Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*
 * config.h -- central configuration header
 *
 */

#ifndef CONFIG_H
#define CONFIG_H

#include "boarddef.h"

/* CPU frequency in Hertz */
#define F_CPU               BOARD_XTAL_FREQ

/* UART configuration */
#define UART_MODE_TEXT             // Filtering for CR and LF enabled
//#define UART_MODE_BINARY         // Data is passed without filtering
#define UART_BAUDRATE       9600   // baud rate
#define UART_TX_BUFSIZE     32     // length of output buffer
#define UART_RX_BUFSIZE     32     // length of input buffer

/* Event system */
#define EVT_QUEUE_LEN       8      // length of event queue (2^n with n >= 1)
#define EVT_MAX_SUBSCR      10     // max. number of subscribers (callbacks)

/* Pulse detection */
#define PULSE_AVG_COUNT     10     // Number of beats to calculate average
#define PULSE_USE_INT              // Use INT0 to detect heart beats
#ifndef PULSE_USE_INT  ////////////// Needed for polling mode only
#define PULSE_SENSE_PIN     PD2    // pin sensor is connected to
#define PULSE_SENSE_OREG    PORTD  // output register
#define PULSE_SENSE_IREG    PIND   // input register
#define PULSE_SENSE_DREG    DDRD   // data direction register
#define PULSE_SENSE_COUNT   10     // debounce count
#endif //////////////////////////////

/* LED and buzzer for visual/acoustic feedback */
#define VIEW_ON_TIME        75               // "on"-time in milliseconds
#define LED_PIN             BOARD_LED1_PIN   // pin number
#define LED_OREG            BOARD_LED1_OREG  // output register
#define LED_DREG            BOARD_LED1_DREG  // data direction register
#define BEEP_PIN            BOARD_BUZZ_PIN   // pin number
#define BEEP_OREG           BOARD_BUZZ_OREG  // output register
#define BEEP_DREG           BOARD_BUZZ_DREG  // data direction register

/* Debug support */
#define DEBUG                                // globally enable debug support
#define ASSERT_PIN          BOARD_LED2_PIN   // pin to toggle in RT_ASSERT
#define ASSERT_OREG         BOARD_LED2_OREG  // output register
#define ASSERT_DREG         BOARD_LED2_DREG  // data direction register

#endif
