/*
 * Copyright (c) 2011, Felix Opatz
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * * Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*
 * pulse.h -- pulse detection
 *
 * The sensed heart rate is made available as current value and as average
 * value (arithmetic mean over the last PULSE_AVG_COUNT values).
 *
 * Public events:
 *   EVT_PULSE_BEAT  heart beat has been sensed
 *
 */

#ifndef PULSE_H
#define PULSE_H

#include <stdint.h>
#include <stdbool.h>

/* Initialization function */
void pulse_init(void);

/* Get current heart rate in beats per minute.
 *
 * Parameters:
 *   curr    pointer to buffer to receive current heart rate
 *
 * Return value:
 *   true     result in buffer is valid
 *   false    buffer is in undefined condition
 */
bool pulse_get_curr(uint8_t *curr);

/* Get average heart rate in beats per minute.
 *
 * Parameters:
 *   curr    pointer to buffer to receive average heart rate
 *
 * Return value:
 *   true     result in buffer is valid
 *   false    buffer is in undefined condition
 */
bool pulse_get_avg(uint8_t *avg);

#endif
