/*
 * Copyright (c) 2011, Felix Opatz
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * * Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*
 * util.h -- utility functions and macros
 *
 * These functions and macros are used in several places. To have only one
 * (hopefully working) definition this header file is used.
 *
 */

#ifndef UTIL_H
#define UTIL_H

#include <avr/interrupt.h>

/* Evaluates to 1 if n is a power of 2 */
#define IS_POWER_OF_TWO(n)  (((n) & ((n)-1)) == 0)

/* Generates a compiler error if exp evaluates to false */
#define CT_ASSERT(exp) \
        extern uint8_t ct_assert[(exp) ? 1 : -1]

#ifdef DEBUG
/* Toggles a pin in an endless loop if exp evaluates to false */
#define RT_ASSERT(exp)                                     \
        if (!(exp)) {                                      \
                cli();                                     \
                ASSERT_DREG |= (1 << ASSERT_PIN);          \
                for (;;)                                   \
                        ASSERT_OREG ^= (1 << ASSERT_PIN);  \
        }
#else
#define RT_ASSERT(exp)
#endif

/* Saves current interrupt setting and disables interrupts globally */
inline void irq_lock(uint8_t *reg)
{
	*reg = SREG;
	cli();
}

/* Restores the interrupt setting previously saved to 'reg' */
inline void irq_unlock(uint8_t reg)
{
	SREG = reg;
}

inline void irq_enable(void)
{
	sei();
}

#endif
